@@ -130,3 +130,17 @@ def format_string(text):
     pattern = re.compile('<[A-Za-z\\/].*?>')
     text = re.sub(pattern, '', text)
     return text
+
+
+def format_number(strNum):
+    if '千' in strNum:
+        strNum = int(float(strNum.split("千")[0]) * 1000)
+    elif '万' in strNum:
+        strNum = int(float(strNum.split("万")[0]) * 10000)
+    elif '百万' in strNum:
+        strNum = int(float(strNum.split("百万")[0]) * 1000000)
+    elif '千万' in strNum:
+        strNum = int(float(strNum.split("千万")[0]) * 10000000)
+    elif '亿' in strNum:
+        strNum = int(float(strNum.split("亿")[0]) * 100000000)
+    return strNum
